PALM-meteo: palmmeteo.utils.DTIndexer Class Reference

PALM-meteo

Public Member Functions | List of all members
palmmeteo.utils.DTIndexer Class Reference

## Public Member Functions
def | __call__ (self, dt)

## Detailed Description

    Calculates integral time index from start and origin. Avoids
    using the unpicklable lambdas.

## Member Function Documentation

## ◆ __call__()

def palmmeteo.utils.DTIndexer.__call__ | ( |  | self,
|  |  | dt
| ) |  |

The documentation for this class was generated from the following file:

- palmmeteo/utils.py